@@ -12,8 +12,8 @@ from mapd import MapD  # noqa
 
 
 apilevel = "2.0"
-threadsafety = 1  # TODO: check
-paramstyle = "qmark"
+threadsafety = 2
+paramstyle = "named"
 
 from .connection import (  # noqa
     connect, Connection
